// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	model "LAPP_LF_MOM_BACKEND/models/base"
	"LAPP_LF_MOM_BACKEND/services/base/implments"
	"LAPP_LF_MOM_BACKEND/web/models"
)

/******************************************************************************
 *
 * @Interface Name           : OpcInfoService
 *-----------------------------------------------------------------------------
 *
 * @Description              : OpcInfo的服务接口
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-14 14:51:48
 *
 ******************************************************************************/
type OpcInfoService interface {
	/******************************************************************************
	 *
	 * @Function Name            : InsertOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入一条OpcInfo
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要插入的OpcInfo
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-07-14 14:51:48
	 *
	 ******************************************************************************/
	InsertOne(*models.Usertab, *model.OpcInfo) error
	/******************************************************************************
	 *
	 * @Function Name            : DeleteOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除指定键的OpcInfo
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-07-14 14:51:48
	 *
	 ******************************************************************************/
	DeleteOne(*models.Usertab, string, int) error
	/******************************************************************************
	 *
	 * @Function Name            : SelectOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查找指定键的OpcInfo
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 查找到的OpcInfo
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-07-14 14:51:48
	 *
	 ******************************************************************************/
	SelectOne(*models.Usertab, string, int) (*model.OpcInfo, error)
	/******************************************************************************
	 *
	 * @Function Name            : UpdateOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改一条OpcInfo
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要修改的OpcInfo
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-07-14 14:51:48
	 *
	 ******************************************************************************/
	UpdateOne(*models.Usertab, *model.OpcInfo) error
	/******************************************************************************
	 *
	 * @Function Name            : Insert
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入多条OpcInfo
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要插入的OpcInfo列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-07-14 14:51:48
	 *
	 ******************************************************************************/
	Insert(*models.Usertab, *[]model.OpcInfo) error
	/******************************************************************************
	 *
	 * @Function Name            : Delete
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除多条OpcInfo
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要删除的OpcInfo列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-07-14 14:51:48
	 *
	 ******************************************************************************/
	Delete(*models.Usertab, *[]model.OpcInfo) error
	/******************************************************************************
	 *
	 * @Function Name            : SelectAndPaging
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查询OpcInfo
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 查询参数
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-07-14 14:51:48
	 *
	 ******************************************************************************/
	Select(*models.Usertab, map[string]string) (interface{}, error)
	/******************************************************************************
	 *
	 * @Function Name            : Update
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改多条OpcInfo
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要修改的OpcInfo列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-07-14 14:51:48
	 *
	 ******************************************************************************/
	Update(*models.Usertab, *[]model.OpcInfo) error
}

/******************************************************************************
 *
 * @Function Name            : NewOpcInfoService
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个OpcInfoService
 *
 * @Return Value             : OpcInfoService实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-14 14:51:48
 *
 ******************************************************************************/
func NewOpcInfoService() OpcInfoService {
	return implments.NewOpcInfoServiceImplement()
}
