// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	dal "LAPP_LF_MOM_BACKEND/dao/base"
	"LAPP_LF_MOM_BACKEND/db"
	"LAPP_LF_MOM_BACKEND/grmi"
	meta "LAPP_LF_MOM_BACKEND/meta/base"
	model "LAPP_LF_MOM_BACKEND/models/base"
	"LAPP_LF_MOM_BACKEND/web/models"
)

/******************************************************************************
 *
 * @Description              : OpcInfo的默认查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-14 14:51:48
 *
 ******************************************************************************/
var DefaultConditionOfOpcInfo = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.OpcInfo_WorkLineId.UrlParameterName:      grmi.NewConditionItem(meta.OpcInfo_WorkLineId, grmi.Equal, true),
		meta.OpcInfo_StepNo.UrlParameterName:          grmi.NewConditionItem(meta.OpcInfo_StepNo, grmi.Equal, true),
		meta.OpcInfo_StepDesc.UrlParameterName:        grmi.NewConditionItem(meta.OpcInfo_StepDesc, grmi.Equal, false),
		meta.OpcInfo_BrandName.UrlParameterName:       grmi.NewConditionItem(meta.OpcInfo_BrandName, grmi.Equal, false),
		meta.OpcInfo_MachineType.UrlParameterName:     grmi.NewConditionItem(meta.OpcInfo_MachineType, grmi.Equal, false),
		meta.OpcInfo_IpAddress.UrlParameterName:       grmi.NewConditionItem(meta.OpcInfo_IpAddress, grmi.Equal, false),
		meta.OpcInfo_RuleId.UrlParameterName:          grmi.NewConditionItem(meta.OpcInfo_RuleId, grmi.Equal, false),
		meta.OpcInfo_ActionType.UrlParameterName:      grmi.NewConditionItem(meta.OpcInfo_ActionType, grmi.Equal, false),
		meta.OpcInfo_DBlockAddress.UrlParameterName:   grmi.NewConditionItem(meta.OpcInfo_DBlockAddress, grmi.Equal, false),
		meta.OpcInfo_DBlockValueType.UrlParameterName: grmi.NewConditionItem(meta.OpcInfo_DBlockValueType, grmi.Equal, false),
		meta.OpcInfo_DBlockValue.UrlParameterName:     grmi.NewConditionItem(meta.OpcInfo_DBlockValue, grmi.Equal, false),
		meta.OpcInfo_LastModify.UrlParameterName:      grmi.NewConditionItem(meta.OpcInfo_LastModify, grmi.Approximate, false),
		meta.OpcInfo_LastUser.UrlParameterName:        grmi.NewConditionItem(meta.OpcInfo_LastUser, grmi.Equal, false),
		meta.OpcInfo_CreateTime.UrlParameterName:      grmi.NewConditionItem(meta.OpcInfo_CreateTime, grmi.Approximate, false),
	},
	nil,
)

/******************************************************************************
 *
 * @Description              : OpcInfo的默认分页查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-14 14:51:48
 *
 ******************************************************************************/
var DefaultConditionOfOpcInfoAndPaging = grmi.NewCondition(
	DefaultConditionOfOpcInfo.Items,
	grmi.NewPaging(),
)

/******************************************************************************
 *
 * @Struct Name              : OpcInfoServiceImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : OpcInfo的服务实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-14 14:51:48
 *
 ******************************************************************************/
type OpcInfoServiceImplement struct {
}

/******************************************************************************
 *
 * @Function Name            : NewOpcInfoDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个OpcInfoDAOImplement实例
 *
 * @Return Value             : OpcInfoDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-14 14:51:48
 *
 ******************************************************************************/
func NewOpcInfoServiceImplement() *OpcInfoServiceImplement {
	return &OpcInfoServiceImplement{}
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/services/base/OpcInfoService.InsertOne
 *
 ******************************************************************************/
func (impl *OpcInfoServiceImplement) InsertOne(user *models.Usertab, entity *model.OpcInfo) error {

	grmi.Log(user, "/services/base/implments/OpcInfo.service.impl.go", "InsertOneOpcInfo", "插入一个OpcInfo")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewOpcInfoDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.WorkLineId, entity.StepNo)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}

	daoWorkLine := dal.NewWorkLineDAO(session, user.Pid, user.Userid)
	recordWorkLine, err := daoWorkLine.SelectOne(entity.WorkLineId)
	if err != nil {
		return err
	}
	if recordWorkLine == nil {
		return grmi.NewBusinessError("不存在指定产线!")
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/services/base/OpcInfoService.DeleteOne
 *
 ******************************************************************************/
func (impl *OpcInfoServiceImplement) DeleteOne(user *models.Usertab, workLineId string, stepNo int) error {

	grmi.Log(user, "/services/base/implments/OpcInfo.service.impl.go", "DeleteOneOpcInfo", "删除一个OpcInfo")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewOpcInfoDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(workLineId, stepNo)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(workLineId, stepNo)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/services/base/OpcInfoService.SelectOne
 *
 ******************************************************************************/
func (impl *OpcInfoServiceImplement) SelectOne(user *models.Usertab, workLineId string, stepNo int) (*model.OpcInfo, error) {

	grmi.Log(user, "/services/base/implments/OpcInfo.service.impl.go", "SelectOneOpcInfo", "查询一个OpcInfo")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewOpcInfoDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(workLineId, stepNo)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/services/base/OpcInfoService.UpdateOne
 *
 ******************************************************************************/
func (impl *OpcInfoServiceImplement) UpdateOne(user *models.Usertab, entity *model.OpcInfo) error {

	grmi.Log(user, "/services/base/implments/OpcInfo.service.impl.go", "UpdateOneOpcInfo", "修改一个OpcInfo")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewOpcInfoDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.WorkLineId, entity.StepNo)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}

	daoWorkLine := dal.NewWorkLineDAO(session, user.Pid, user.Userid)
	recordWorkLine, err := daoWorkLine.SelectOne(entity.WorkLineId)
	if err != nil {
		return err
	}
	if recordWorkLine == nil {
		return grmi.NewBusinessError("不存在指定产线!")
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/services/base/OpcInfoService.Insert
 *
 ******************************************************************************/
func (impl *OpcInfoServiceImplement) Insert(user *models.Usertab, entities *[]model.OpcInfo) error {

	grmi.Log(user, "/services/base/implments/OpcInfo.service.impl.go", "InsertOpcInfo", "插入多个OpcInfo")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewOpcInfoDAO(session, user.Pid, user.Userid)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.WorkLineId, entity.StepNo)
		if err != nil {
			return err
		}
		if record != nil {
			return grmi.NewBusinessError("已经存在相同主键的记录!")
		}
	}

	err := dao.Insert(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/services/base/OpcInfoService.Delete
 *
 ******************************************************************************/
func (impl *OpcInfoServiceImplement) Delete(user *models.Usertab, entities *[]model.OpcInfo) error {

	grmi.Log(user, "/services/base/implments/OpcInfo.service.impl.go", "DeleteOpcInfo", "删除多个OpcInfo")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewOpcInfoDAO(session, user.Pid, user.Userid)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.WorkLineId, entity.StepNo)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Delete(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/services/base/OpcInfoService.Select
 *
 ******************************************************************************/
func (impl *OpcInfoServiceImplement) Select(user *models.Usertab, urlParameters map[string]string) (interface{}, error) {

	grmi.Log(user, "/services/base/implments/OpcInfo.service.impl.go", "SelectOpcInfo", "查询OpcInfo")

	condition := DefaultConditionOfOpcInfoAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewOpcInfoDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/services/base/OpcInfoService.Update
 *
 ******************************************************************************/
func (impl *OpcInfoServiceImplement) Update(user *models.Usertab, entities *[]model.OpcInfo) error {

	grmi.Log(user, "/services/base/implments/OpcInfo.service.impl.go", "UpdateOpcInfo", "修改多个OpcInfo")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewOpcInfoDAO(session, user.Pid, user.Userid)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.WorkLineId, entity.StepNo)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Update(entities)
	if err != nil {
		return err
	}
	return nil
}
