// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package om

import (
	model "LAPP_LF_MOM_BACKEND/models/om"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneSerialOrderStepStatusRecLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条SerialOrderStepStatusRecLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterOneSerialOrderStepStatusRecLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.SerialOrderStepStatusRecLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.SerialOrderStepStatusRecLst)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfSerialOrderStepStatusRecLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条SerialOrderStepStatusRecLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterIDOfSerialOrderStepStatusRecLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, string, int, int, int) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		serialOrderId := ctx.Params().GetString("serialOrderId")
		workPlaceNr, err := ctx.Params().GetInt("workPlaceNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		stepNo, err := ctx.Params().GetInt("stepNo")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		pos, err := ctx.Params().GetInt("pos")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, serialOrderId, workPlaceNr, stepNo, pos)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneSerialOrderStepStatusRecLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条SerialOrderStepStatusRecLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterInsertOneSerialOrderStepStatusRecLst(party router.Party, path string, method func(*models.Usertab, *model.SerialOrderStepStatusRecLst) error) {

	RegisterOneSerialOrderStepStatusRecLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneSerialOrderStepStatusRecLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条SerialOrderStepStatusRecLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterDeleteOneSerialOrderStepStatusRecLst(party router.Party, path string, method func(*models.Usertab, string, int, int, int) error) {

	RegisterIDOfSerialOrderStepStatusRecLst(party, "DELETE", path+"/{serialOrderId:string}/{workPlaceNr:int}/{stepNo:int}/{pos:int}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneSerialOrderStepStatusRecLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条SerialOrderStepStatusRecLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterSelectOneSerialOrderStepStatusRecLst(party router.Party, path string, method func(*models.Usertab, string, int, int, int) (*model.SerialOrderStepStatusRecLst, error)) {

	party.Get(path+"/{serialOrderId:string}/{workPlaceNr:int}/{stepNo:int}/{pos:int}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		serialOrderId := ctx.Params().GetString("serialOrderId")
		workPlaceNr, err := ctx.Params().GetInt("workPlaceNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		stepNo, err := ctx.Params().GetInt("stepNo")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		pos, err := ctx.Params().GetInt("pos")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		result, err := method(user, serialOrderId, workPlaceNr, stepNo, pos)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneSerialOrderStepStatusRecLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条SerialOrderStepStatusRecLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterUpdateOneSerialOrderStepStatusRecLst(party router.Party, path string, method func(*models.Usertab, *model.SerialOrderStepStatusRecLst) error) {

	RegisterOneSerialOrderStepStatusRecLst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiSerialOrderStepStatusRecLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条SerialOrderStepStatusRecLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterMultiSerialOrderStepStatusRecLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.SerialOrderStepStatusRecLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.SerialOrderStepStatusRecLst, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertSerialOrderStepStatusRecLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条SerialOrderStepStatusRecLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterInsertSerialOrderStepStatusRecLst(party router.Party, path string, method func(*models.Usertab, *[]model.SerialOrderStepStatusRecLst) error) {

	RegisterMultiSerialOrderStepStatusRecLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteSerialOrderStepStatusRecLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条SerialOrderStepStatusRecLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterDeleteSerialOrderStepStatusRecLst(party router.Party, path string, method func(*models.Usertab, *[]model.SerialOrderStepStatusRecLst) error) {

	RegisterMultiSerialOrderStepStatusRecLst(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectSerialOrderStepStatusRecLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询SerialOrderStepStatusRecLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterSelectSerialOrderStepStatusRecLst(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateSerialOrderStepStatusRecLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条SerialOrderStepStatusRecLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterUpdateSerialOrderStepStatusRecLst(party router.Party, path string, method func(*models.Usertab, *[]model.SerialOrderStepStatusRecLst) error) {

	RegisterMultiSerialOrderStepStatusRecLst(party, "PUT", path, method)
}
