// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package om

import (
	model "LAPP_LF_MOM_BACKEND/models/om"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneSerialOrderWPStatusRecLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条SerialOrderWPStatusRecLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterOneSerialOrderWPStatusRecLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.SerialOrderWPStatusRecLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.SerialOrderWPStatusRecLst)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfSerialOrderWPStatusRecLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条SerialOrderWPStatusRecLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterIDOfSerialOrderWPStatusRecLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, string, int, int, int) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		serialOrderId := ctx.Params().GetString("serialOrderId")
		workPlaceNr, err := ctx.Params().GetInt("workPlaceNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		originPos, err := ctx.Params().GetInt("originPos")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		pos, err := ctx.Params().GetInt("pos")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, serialOrderId, workPlaceNr, originPos, pos)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneSerialOrderWPStatusRecLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条SerialOrderWPStatusRecLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterInsertOneSerialOrderWPStatusRecLst(party router.Party, path string, method func(*models.Usertab, *model.SerialOrderWPStatusRecLst) error) {

	RegisterOneSerialOrderWPStatusRecLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneSerialOrderWPStatusRecLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条SerialOrderWPStatusRecLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterDeleteOneSerialOrderWPStatusRecLst(party router.Party, path string, method func(*models.Usertab, string, int, int, int) error) {

	RegisterIDOfSerialOrderWPStatusRecLst(party, "DELETE", path+"/{serialOrderId:string}/{workPlaceNr:int}/{originPos:int}/{pos:int}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneSerialOrderWPStatusRecLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条SerialOrderWPStatusRecLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterSelectOneSerialOrderWPStatusRecLst(party router.Party, path string, method func(*models.Usertab, string, int, int, int) (*model.SerialOrderWPStatusRecLst, error)) {

	party.Get(path+"/{serialOrderId:string}/{workPlaceNr:int}/{originPos:int}/{pos:int}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		serialOrderId := ctx.Params().GetString("serialOrderId")
		workPlaceNr, err := ctx.Params().GetInt("workPlaceNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		originPos, err := ctx.Params().GetInt("originPos")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		pos, err := ctx.Params().GetInt("pos")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		result, err := method(user, serialOrderId, workPlaceNr, originPos, pos)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneSerialOrderWPStatusRecLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条SerialOrderWPStatusRecLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterUpdateOneSerialOrderWPStatusRecLst(party router.Party, path string, method func(*models.Usertab, *model.SerialOrderWPStatusRecLst) error) {

	RegisterOneSerialOrderWPStatusRecLst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiSerialOrderWPStatusRecLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条SerialOrderWPStatusRecLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterMultiSerialOrderWPStatusRecLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.SerialOrderWPStatusRecLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.SerialOrderWPStatusRecLst, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertSerialOrderWPStatusRecLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条SerialOrderWPStatusRecLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterInsertSerialOrderWPStatusRecLst(party router.Party, path string, method func(*models.Usertab, *[]model.SerialOrderWPStatusRecLst) error) {

	RegisterMultiSerialOrderWPStatusRecLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteSerialOrderWPStatusRecLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条SerialOrderWPStatusRecLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterDeleteSerialOrderWPStatusRecLst(party router.Party, path string, method func(*models.Usertab, *[]model.SerialOrderWPStatusRecLst) error) {

	RegisterMultiSerialOrderWPStatusRecLst(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectSerialOrderWPStatusRecLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询SerialOrderWPStatusRecLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterSelectSerialOrderWPStatusRecLst(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateSerialOrderWPStatusRecLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条SerialOrderWPStatusRecLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterUpdateSerialOrderWPStatusRecLst(party router.Party, path string, method func(*models.Usertab, *[]model.SerialOrderWPStatusRecLst) error) {

	RegisterMultiSerialOrderWPStatusRecLst(party, "PUT", path, method)
}
